function [res, isSuccess] = query(obj, sql, sqlInfo)
%QUERY query database using adodb, return the result
%
%   [res, isSuccess] = adodb.query(sql, ado_connection_string), query the
%   database which is specified by ado_connection_string.
%
%   You don't need to write the full ado_connection_string, actually, you
%   only need to provide the information, i.e, the input could be a 5*1
%   cells, or a struct with fields 'type', 'server', 'databasename',
%   'user', 'password'.
%
% Example:
%   ado = adodb;
%   res = ado.query('select * from TestTable order by lastname, firstname',
%   {'Access', [], '\adotest.mdb']);
%
% See also: adodb/queryone, adodb/connstr
%
% Copyright: zhang@zhiqiang.org, 2010
% http://zhiqiang.org/blog/tag/matlab

if nargin >= 3, obj.setconn(sqlInfo); end

sql = strtrim(sql);
obj.sql = sql;

% if strcmpi('select', sql(1:min(6, numel(sql)))) % select database
% open recordset and run query
obj.conn.BeginTrans();
try
    res = obj.conn.Execute(sql);
    obj.conn.CommitTrans();
    isSuccess = 1;
catch %#ok<CTCH>
    obj.conn.RollbackTrans();
    isSuccess = 0;
end

% because the sql could be update or insert the database
try
    %retrieve data from recordset
    if res.recordcount > 0
        res = (res.GetRows())';
    else
        res = {};
    end
catch %#ok<CTCH>
    disp(['The database is modified by sql ' obj.sql]);
end